"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Class used to handle the initial verification of a newly added webhook endpoint to Facebook. To be used with the GET
 * route as that is the method used by Facebook for token verification.
 */
class ValidateWebhook {
    /* istanbul ignore next line */
    constructor() { }
    /**
     * Method to be used if there is env variable FB_VERIFICATION_TOKEN added as it will extract it by itself.
     * @param req - The request object from server
     * @param res - The response object from server
     */
    static validate(req, res) {
        const fbToken = process.env.FB_VERIFICATION_TOKEN;
        this.verifyToken(req, res, fbToken);
    }
    /**
     * Method to be used if verification token is passed in via another method/variable.
     * @param req - The request object from server
     * @param res - The response object from server
     * @param token - The Facebook token
     */
    static validateWithToken(req, res, token) {
        this.verifyToken(req, res, token);
    }
    static verifyToken(req, res, facebookToken) {
        const tokenPresent = facebookToken != null;
        const remoteTokenPresent = req != null && typeof req.query !== 'undefined' && typeof req.query['hub.verify_token'] !== 'undefined';
        if (tokenPresent && remoteTokenPresent) {
            if (req.query['hub.verify_token'] === facebookToken) {
                res.status(200).send(req.query['hub.challenge']);
            }
            else {
                res.sendStatus(403);
            }
        }
        else {
            res.sendStatus(403);
        }
    }
}
exports.ValidateWebhook = ValidateWebhook;
//# sourceMappingURL=ValidateWebhook.js.map